@@ -30,9 +30,14 @@ struct _FileSelData
   void (*click_ok_callback)(GtkButton*, gpointer);
   void (*click_cancel_callback)(GtkButton*, gpointer);
   GtkWidget *filesel;
+  
 };
   
 GtkWidget*
 create_fileselection_gui (FileSelData *fd);
 
-#endif
\ No newline at end of file
+gchar*
+fileselection_get_filename(gchar* title, gchar* init_path, gchar* filter);
+
+#endif
+
