@@ -20,6 +20,7 @@
 #ifndef _GNOME_PROJECT_H_
 #define _GNOME_PROJECT_H_
 
-void create_new_project(AppWidzard* aw);
+gboolean
+create_new_project (AppWidzard * aw);
 
 #endif
