@@ -26,7 +26,9 @@
 #include "support.h"
 #include "anjuta.h"
 
-AnjutaApp *app;  //one and only one instance of AnjutaApp.
+/* One and only one instance of AnjutaApp. */
+AnjutaApp *app;			
+
 int arg_c;
 char **arg_v;
 
@@ -35,16 +37,23 @@ main (int argc, char *argv[])
 {
 
 #ifdef ENABLE_NLS
-   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
-   textdomain (PACKAGE);
+	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+	textdomain (PACKAGE);
 #endif
 
-  gnome_init ("anjuta", VERSION, argc, argv);
-  arg_c = argc;
-  arg_v = argv;
-  splash_screen();
-  anjuta_new();
-  anjuta_show();
-  gtk_main ();
-  return 0;
+	gnome_init ("anjuta", VERSION, argc, argv);
+	
+	/* Session management is under development */
+	gnome_client_disable_master_connection ();
+	arg_c = argc;
+	arg_v = argv;
+
+#ifndef ANJUTA_DISABLE_SPLASH
+	splash_screen ();
+#endif
+
+	anjuta_new ();
+	anjuta_show ();
+	gtk_main ();
+	return 0;
 }
